@@ -16,6 +16,8 @@ from .py_op_exceptions import (
     OPDocumentGetException,
     OPGroupGetException,
     OPGroupListException,
+    OPItemCreateException,
+    OPItemDeleteException,
     OPItemGetException,
     OPItemListException,
     OPNotSignedInException,
@@ -54,27 +56,15 @@ class _OPCommandInterface(_OPCLIExecute):
     OP_PATH = 'op'  # let subprocess find 'op' in the system path
 
     def __init__(self,
-                 vault=None,
                  account=None,
                  password=None,
-                 logger=None,
-                 op_path=OP_PATH,
                  existing_auth: ExistingAuthEnum = EXISTING_AUTH_IGNORE,
-                 password_prompt=True):
+                 vault=None,
+                 password_prompt=True,
+                 op_path=OP_PATH,
+                 logger=None):
         """
-        Create an OP object. The 1Password sign-in happens during object instantiation.
-        If 'password' is not provided, the 'op' command will prompt on the console for a password.
-
-        Arguments:
-            - 'account_shorthand': The shorthand name for the account on this device.
-                                   See 'op signin --help' for more information.
-            - 'password': The user's master password
-            - 'logger': A logging object. If not provided a basic logger is created and used.
-            - 'op_path': optional path to the `op` command, if it's not at the default location
-
-        Raises:
-            - OPSigninException if 1Password sign-in fails for any reason.
-            - OPNotFoundException if the 1Password command can't be found.
+        Constructor to authenticate or verify existing authentication to `op`
         """
         super().__init__()
         if not logger:
@@ -330,13 +320,20 @@ class _OPCommandInterface(_OPCLIExecute):
         argv = _OPArgv.account_list_argv(op_path, encoding=encoding)
         return argv
 
-    def _item_get_argv(self, item_name_or_id, vault=None, fields=None):
+    def _item_get_argv(self, item_name_or_id, vault=None, fields=None, include_archive=False):
         vault_arg = vault if vault else self.vault
 
         lookup_argv = _OPArgv.item_get_argv(
-            self.op_path, item_name_or_id, vault=vault_arg, fields=fields)
+            self.op_path, item_name_or_id, vault=vault_arg, fields=fields, include_archive=include_archive)
         return lookup_argv
 
+    def _item_delete_argv(self, item_name_or_id, vault=None, archive=False):
+        vault_arg = vault if vault else self.vault
+
+        delete_argv = _OPArgv.item_delete_argv(
+            self.op_path, item_name_or_id, vault=vault_arg, archive=archive)
+        return delete_argv
+
     def _item_get_totp_argv(self, item_name_or_id, vault=None):
         vault_arg = vault if vault else self.vault
 
@@ -382,9 +379,9 @@ class _OPCommandInterface(_OPCLIExecute):
             self.op_path, group_name_or_id=group_name_or_id, user_name_or_id=user_name_or_id)
         return vault_list_argv
 
-    def _item_get(self, item_name_or_id, vault=None, fields=None, decode="utf-8"):
+    def _item_get(self, item_name_or_id, vault=None, fields=None, include_archive=False, decode="utf-8"):
         get_item_argv = self._item_get_argv(
-            item_name_or_id, vault=vault, fields=fields)
+            item_name_or_id, vault=vault, fields=fields, include_archive=include_archive)
         try:
             output = self._run(
                 get_item_argv, capture_stdout=True, decode=decode)
@@ -393,6 +390,18 @@ class _OPCommandInterface(_OPCLIExecute):
 
         return output
 
+    def _item_delete(self, item_name_or_id, vault=None, archive=False, decode="utf-8"):
+        item_delete_argv = self._item_delete_argv(
+            item_name_or_id, vault=vault, archive=archive)
+        try:
+            # 'op item delete' doesn't have any output if successful
+            # if it fails, stderr will be in the exception object
+            self._run(item_delete_argv, decode=decode)
+        except OPCmdFailedException as ocfe:
+            raise OPItemDeleteException.from_opexception(ocfe)
+
+        return
+
     def _item_get_totp(self, item_name_or_id, vault=None, decode="utf-8"):
         item_get_totp_argv = self._item_get_totp_argv(
             item_name_or_id, vault=vault)
@@ -532,3 +541,19 @@ class _OPCommandInterface(_OPCLIExecute):
         except OPCmdFailedException as e:
             raise OPItemListException.from_opexception(e)
         return output
+
+    def _item_create_argv(self, item, password_recipe, vault):
+        vault_arg = vault if vault else self.vault
+        create_item_argv = _OPArgv.item_create_argv(
+            self.op_path, item, password_recipe=password_recipe, vault=vault_arg
+        )
+        return create_item_argv
+
+    def _item_create(self, item, vault, password_recipe, decode="utf-8"):
+        argv = self._item_create_argv(item, password_recipe, vault)
+        try:
+            output = self._run(argv, capture_stdout=True, decode=decode)
+        except OPCmdFailedException as e:
+            raise OPItemCreateException.from_opexception(e)
+
+        return output
