@@ -1,5 +1,11 @@
+from ..op_items._new_fields import OPNewTOTPUriException
 from ..op_items._op_item_type_registry import OPUnknownItemTypeException
-from ..op_items._op_items_base import OPFieldNotFoundException
+from ..op_items._op_items_base import (
+    OPFieldNotFoundException,
+    OPSectionCollisionException,
+    OPSectionNotFoundException
+)
+from ..op_items.login import OPNewLoginItemURLException
 from ..op_objects import (
     OPInvalidGroupException,
     OPInvalidGroupListException,
@@ -18,6 +24,7 @@ from ..py_op_exceptions import (
     OPGroupListException,
     OPInvalidDocumentException,
     OPInvalidItemException,
+    OPItemDeleteException,
     OPItemGetException,
     OPItemListException,
     OPNotFoundException,
