@@ -16,6 +16,9 @@ class OPItemFactory:
 
     @classmethod
     def register_op_item_type(cls, item_type, item_class):
+        if item_type in cls._TYPE_REGISTRY:
+            raise Exception(  # pragma: no coverage
+                f"duplicate for item type {item_type}: {item_class}")
         cls._TYPE_REGISTRY[item_type] = item_class
 
     @classmethod
