@@ -47,14 +47,14 @@ class OPSigninException(OPCmdFailedException):
         super().__init__(stderr_out, returncode)
 
 
-class OPSignoutException(OPCmdFailedException):
+class OPSignoutException(OPCmdFailedException):  # pragma: no coverage
     MSG = "1Password signout failed."
 
     def __init__(self, stderr_out, returncode):
         super().__init__(stderr_out, returncode)
 
 
-class OPForgetException(OPCmdFailedException):
+class OPForgetException(OPCmdFailedException):  # pragma: no coverage
     MSG = "1Password forget failed."
 
     def __init__(self, stderr_out, returncode):
@@ -75,6 +75,13 @@ class OPItemListException(OPCmdFailedException):
         super().__init__(stderr_out, returncode)
 
 
+class OPItemDeleteException(OPCmdFailedException):
+    MSG = "1Password 'item delete' failed."
+
+    def __init__(self, stderr_out, returncode):
+        super().__init__(stderr_out, returncode)
+
+
 class OPDocumentGetException(OPCmdFailedException):
     MSG = "1Password 'get document' failed."
 
@@ -124,6 +131,13 @@ class OPGroupListException(OPCmdFailedException):
         super().__init__(stderr_out, returncode)
 
 
+class OPItemCreateException(OPCmdFailedException):  # pragma: no coverage
+    MSG = "1Password 'item create' failed."
+
+    def __init__(self, stderr_out, returncode):
+        super().__init__(stderr_out, returncode)
+
+
 class OPInvalidItemException(_OPAbstractException):
     def __init__(self, msg):
         super().__init__(msg)
@@ -152,6 +166,11 @@ class OPConfigNotFoundException(Exception):
     pass
 
 
+class OPInvalidFieldException(_OPAbstractException):
+    def __init__(self, msg):
+        super().__init__(msg)
+
+
 class OPUnknownAccountException(_OPAbstractException):
     def __init__(self, msg):
         super().__init__(msg)
